<?php

namespace Litecms\Legal\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Legal\Actions\LegalAction;
use Litecms\Legal\Http\Requests\LegalActionRequest;
use Litecms\Legal\Http\Resources\LegalResource;
use Litecms\Legal\Models\Legal;

/**
 * Admin web controller class.
 */
class LegalActionController extends BaseController
{

    /**
     * Action controller function for legal.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LegalActionRequest $request, Legal $legal, $action)
    {
        try {
            $request = $request->all();
            $legal = LegalAction::run($action, $legal, $request);

            $data = new LegalResource($legal);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('legal::legal.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('legal/legal/' . $legal->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('legal/legal/' . $legal->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
