<?php

namespace Litecms\Legal\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Legal\Actions\LegalCaseAction;
use Litecms\Legal\Http\Requests\LegalCaseActionRequest;
use Litecms\Legal\Http\Resources\LegalCaseResource;
use Litecms\Legal\Models\LegalCase;

/**
 * Admin web controller class.
 */
class LegalCaseActionController extends BaseController
{

    /**
     * Action controller function for legal_case.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LegalCaseActionRequest $request, LegalCase $legal_case, $action)
    {
        try {
            $request = $request->all();
            $legal_case = LegalCaseAction::run($action, $legal_case, $request);

            $data = new LegalCaseResource($legal_case);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('legal::legal_case.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('legal/legal_case/' . $legal_case->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('legal/legal_case/' . $legal_case->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
