<?php
namespace Litecms\Legal\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Legal\Events\LegalCaseAction as LegalCaseActionEvent;
use Litecms\Legal\Models\LegalCase;

class LegalCaseAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $legal_case;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param LegalCaseActionEvent $legal_case
     */
    public function __construct(LegalCaseActionEvent $legal_case)
    {
        $this->action = $event->action;
        $this->legal_case = $legal_case;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('LegalCase Approved - ' . config('app.name'))
            ->view('legal::legal_case.email.action', ['data' => $this->legal_case]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
